==> jc-1.4.0.tar.gz: java/net/ContentHandler.h <==
// public abstract class java.net.ContentHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4d87ebfc52d36524 java_net_ContentHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_ContentHandler_H_
#define _JC_java_net_ContentHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_net_URLConnection$object;

// Typedefs
typedef struct _jc_java_net_ContentHandler$sub_refs	_jc_java_net_ContentHandler$sub_refs;
typedef struct _jc_java_net_ContentHandler$sub_nonrefs	_jc_java_net_ContentHandler$sub_nonrefs;
typedef struct _jc_java_net_ContentHandler$refs	_jc_java_net_ContentHandler$refs;
typedef struct _jc_java_net_ContentHandler$nonrefs	_jc_java_net_ContentHandler$nonrefs;
typedef struct _jc_java_net_ContentHandler$object	_jc_java_net_ContentHandler$object;

typedef const struct _jc_java_net_ContentHandler$vmethods	_jc_java_net_ContentHandler$vmethods;
typedef const struct _jc_java_net_ContentHandler$vtable	_jc_java_net_ContentHandler$vtable;
typedef const struct _jc_java_net_ContentHandler$vtype	_jc_java_net_ContentHandler$vtype;

// Constructors
extern void _jc_java_net_ContentHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_ContentHandler$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_net_ContentHandler$method$getContent$677478719bf4670d(_jc_env *, struct _jc_java_net_ContentHandler$object *, struct _jc_java_net_URLConnection$object *);
extern struct _jc_java_lang_Object$object *_jc_java_net_ContentHandler$method$getContent$ec7ec17441ac55e5(_jc_env *, struct _jc_java_net_ContentHandler$object *, struct _jc_java_net_URLConnection$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_java_net_ContentHandler$method_info$getContent$677478719bf4670d;
extern _jc_method _jc_java_net_ContentHandler$method_info$getContent$ec7ec17441ac55e5;

// Virtual methods structure
struct _jc_java_net_ContentHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*getContent$677478719bf4670d)(_jc_env *, struct _jc_java_net_ContentHandler$object *, struct _jc_java_net_URLConnection$object *);
	struct _jc_java_lang_Object$object	*(*getContent$ec7ec17441ac55e5)(_jc_env *, struct _jc_java_net_ContentHandler$object *, struct _jc_java_net_URLConnection$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_java_net_ContentHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_ContentHandler$vmethods	java_net_ContentHandler;
};

// Vtype
struct _jc_java_net_ContentHandler$vtype {
	_jc_type			type;
	_jc_java_net_ContentHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_ContentHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_ContentHandler$refs {
    _jc_java_net_ContentHandler$sub_refs	java_net_ContentHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_ContentHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_ContentHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_ContentHandler$sub_nonrefs	java_net_ContentHandler;
};

// Object instance structure
struct _jc_java_net_ContentHandler$object {
	_jc_java_net_ContentHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_ContentHandler$vtype	*vtype;
	_jc_java_net_ContentHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_ContentHandler$vtype _jc_java_net_ContentHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_ContentHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_ContentHandler$class_object;

#endif	/* _JC_java_net_ContentHandler_H_ */

==> jc-1.4.6.tar.gz: java/net/ContentHandler.h <==
// public abstract class java.net.ContentHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4d87ebfc52d36524 java_net_ContentHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_ContentHandler_H_
#define _JC_java_net_ContentHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_net_URLConnection$object;

// Typedefs
typedef struct _jc_java_net_ContentHandler$sub_refs	_jc_java_net_ContentHandler$sub_refs;
typedef struct _jc_java_net_ContentHandler$sub_nonrefs	_jc_java_net_ContentHandler$sub_nonrefs;
typedef struct _jc_java_net_ContentHandler$refs	_jc_java_net_ContentHandler$refs;
typedef struct _jc_java_net_ContentHandler$nonrefs	_jc_java_net_ContentHandler$nonrefs;
typedef struct _jc_java_net_ContentHandler$object	_jc_java_net_ContentHandler$object;

typedef const struct _jc_java_net_ContentHandler$vmethods	_jc_java_net_ContentHandler$vmethods;
typedef const struct _jc_java_net_ContentHandler$vtable	_jc_java_net_ContentHandler$vtable;
typedef const struct _jc_java_net_ContentHandler$vtype	_jc_java_net_ContentHandler$vtype;

// Constructors
extern void _jc_java_net_ContentHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_ContentHandler$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_net_ContentHandler$method$getContent$677478719bf4670d(_jc_env *, struct _jc_java_net_ContentHandler$object *, struct _jc_java_net_URLConnection$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_net_ContentHandler$method$getContent$ec7ec17441ac55e5(_jc_env *, struct _jc_java_net_ContentHandler$object *, struct _jc_java_net_URLConnection$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_ContentHandler$method_info$getContent$677478719bf4670d;
extern _jc_method _jc_java_net_ContentHandler$method_info$getContent$ec7ec17441ac55e5;

// Virtual methods structure
struct _jc_java_net_ContentHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*getContent$677478719bf4670d)(_jc_env *, struct _jc_java_net_ContentHandler$object *, struct _jc_java_net_URLConnection$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getContent$ec7ec17441ac55e5)(_jc_env *, struct _jc_java_net_ContentHandler$object *, struct _jc_java_net_URLConnection$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_ContentHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_ContentHandler$vmethods	java_net_ContentHandler;
};

// Vtype
struct _jc_java_net_ContentHandler$vtype {
	_jc_type			type;
	_jc_java_net_ContentHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_ContentHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_ContentHandler$refs {
    _jc_java_net_ContentHandler$sub_refs	java_net_ContentHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_ContentHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_ContentHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_ContentHandler$sub_nonrefs	java_net_ContentHandler;
};

// Object instance structure
struct _jc_java_net_ContentHandler$object {
	_jc_java_net_ContentHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_ContentHandler$vtype	*vtype;
	_jc_java_net_ContentHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_ContentHandler$vtype _jc_java_net_ContentHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_ContentHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_ContentHandler$class_object;

#endif	/* _JC_java_net_ContentHandler_H_ */
